# AutomatiseCA Documentation

Domenico De Cristofaro

## About

AutomatizeCA is an automated transcription program for linguists and conversation analyst experts.

It is designed to be used for generating Conversation Analysis transcripts that can be improved manually.

## Overview

AutomatizeCA takes in a recorded speech and uses a Speech to Text API to generate a time-aligned transcript. It uses a system of functions to detect the pauses between the turns, to assign the speaker lables to the transcripts and to report and replace the backchannels.

AutomatizeCA renders the final transcript in a txt file including the formats of the Jefferson Transcription System.

**VERSION: 0.0.1**

This is a beta version, further implementation will be done in the future.

## Installation

**Pre-requisites**

In order to use AutomatizeCA, you should have some familiarity with using the terminal to install and run programs.

You should also be aware that AutomatiseCA uses [IBM Watson&#39;s STT API]
(https://cloud.ibm.com/apidocs/speech-to-text)




